==> rendition-9.4.0.tgz: package/dist_esm5/components/Checkbox.js <==
import * as tslib_1 from "tslib";
import { CheckBox as GrommetCheckbox, } from 'grommet';
import * as React from 'react';
import styled from 'styled-components';
import asRendition from '../asRendition';
export var getHoverStyle = function (props) { return "\n\t& label:hover input:not([disabled]) + span > span {\n\t\tborder-color: " + props.theme.colors.primary.dark + ";\n\t\tbackground: " + props.theme.colors.primary.dark + ";\n\t}\n\t& label:hover input:not([disabled]) + div {\n\t\tborder-color: " + props.theme.colors.tertiary.main + "!important;\n\t}\n\t& label:hover input[checked]:not([disabled]) + div {\n\t\tborder-color: " + props.theme.colors.primary.dark + "!important;\n\t\tbackground: " + props.theme.colors.primary.dark + ";\n\t}\n"; };
var getBaseStyle = function (props) { return "\n\t& > label > span {\n\t\tfont-family: " + props.theme.font + ";\n\t}\n\t& label input[checked] + div {\n\t\tborder-color: " + props.theme.colors.primary.main + ";\n\t\tbackground: " + props.theme.colors.primary.main + ";\n\t\t> svg {\n\t\t\tstroke: #fff;\n\t\t}\n\t}\n\t& label[disabled] {\n\t\topacity: 0.4\n\t}\n"; };
var CheckboxWrapper = styled.div(templateObject_1 || (templateObject_1 = tslib_1.__makeTemplateObject(["\n\t", "\n\t", "\n"], ["\n\t", "\n\t", "\n"])), getBaseStyle, getHoverStyle);
var Checkbox = function (props) {
    return (React.createElement(CheckboxWrapper, null,
        React.createElement(GrommetCheckbox, tslib_1.__assign({}, props))));
};
export default asRendition(Checkbox);
var templateObject_1;

==> rendition-11.12.1.tgz: package/dist_esm5/components/Checkbox.js <==
import { __assign, __makeTemplateObject } from "tslib";
import { CheckBox as GrommetCheckbox, } from 'grommet';
import * as React from 'react';
import styled from 'styled-components';
import asRendition from '../asRendition';
export var getHoverStyle = function (props) { return "\n\t& label:hover input:not([disabled]) + span > span {\n\t\tborder-color: " + props.theme.colors.primary.dark + ";\n\t\tbackground: " + props.theme.colors.primary.dark + ";\n\t}\n\t& label:hover input:not([disabled]) + div {\n\t\tborder-color: " + props.theme.colors.tertiary.main + "!important;\n\t}\n\t& label:hover input[checked]:not([disabled]) + div {\n\t\tborder-color: " + props.theme.colors.primary.dark + "!important;\n\t\tbackground: " + props.theme.colors.primary.dark + ";\n\t}\n"; };
var getBaseStyle = function (props) { return "\n\t& > label > span {\n\t\tfont-family: " + props.theme.font + ";\n\t}\n\t& label input[checked] + div {\n\t\tborder-color: " + props.theme.colors.primary.main + ";\n\t\tbackground: " + props.theme.colors.primary.main + ";\n\t\t> svg {\n\t\t\tstroke: #fff;\n\t\t}\n\t}\n\t& label[disabled] {\n\t\topacity: 0.4\n\t}\n"; };
var CheckboxWrapper = styled.div(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\t", "\n\t", "\n"], ["\n\t", "\n\t", "\n"])), getBaseStyle, getHoverStyle);
var Checkbox = function (props) {
    return (React.createElement(CheckboxWrapper, null,
        React.createElement(GrommetCheckbox, __assign({}, props))));
};
export default asRendition(Checkbox);
var templateObject_1;
